@@ -1,6 +1,11 @@
 package Chart::Clicker::Axis::DateTime;
+BEGIN {
+  $Chart::Clicker::Axis::DateTime::VERSION = '2.70';
+}
 use Moose;
 
+# ABSTRACT: An X or Y Axis using DateTime
+
 use Chart::Clicker::Data::Marker;
 
 use DateTime;
@@ -9,11 +14,13 @@ use Graphics::Color::RGB;
 
 extends 'Chart::Clicker::Axis';
 
+
 has 'format' => (
     is => 'rw',
     isa => 'Str'
 );
 
+
 has 'time_zone' => (
     is => 'rw',
     isa => 'Str'
@@ -29,8 +36,8 @@ override 'prepare' => sub {
     };
 
     if(!defined($dstart) || !defined($dend)) {
-        $dstart = DateTime->now();
-        $dend = DateTime->now();
+        $dstart = DateTime->now;
+        $dend = DateTime->now;
     }
 
     my $dur = $dend - $dstart;
@@ -49,14 +56,14 @@ override 'prepare' => sub {
         }
     }
 
-    super();
+    super;
 
-    my $clicker = shift();
+    my $clicker = shift;
     if(!defined($clicker)) {
         die('No clicker?')
     }
 
-    # my @markers = @{ $clicker->markers() };
+    # my @markers = @{ $clicker->markers };
 
     my $set = DateTime::Span->from_datetimes(
         start => $dstart, end => $dend
@@ -73,20 +80,20 @@ override 'prepare' => sub {
     # my $day = $set->start->truncate(to => 'day');
     # 
     # my $dayval;
-    # while($day < $set->end()) {
+    # while($day < $set->end) {
     #     if($set->contains($day)) {
     #         if(defined($dayval)) {
     #             push(@dmarkers,
     #                 Chart::Clicker::Data::Marker->new({
     #                     key         => $dayval,
-    #                     key2        => $day->epoch(),
+    #                     key2        => $day->epoch,
     #                     color       => $linecolor,
     #                     inside_color=> $fillcolor,
     #                 })
     #             );
     #             $dayval = undef;
     #         } else {
-    #             $dayval = $day->epoch();
+    #             $dayval = $day->epoch;
     #         }
     #     }
     #     $day = $day->add(days => 1);
@@ -95,7 +102,7 @@ override 'prepare' => sub {
     #     push(@dmarkers,
     #         Chart::Clicker::Data::Marker->new({
     #             key         => $dayval,
-    #             key2        => $day->epoch(),
+    #             key2        => $day->epoch,
     #             color       => $linecolor,
     #             inside_color=> $fillcolor,
     #         })
@@ -108,19 +115,20 @@ override 'prepare' => sub {
     return 1;
 };
 
+
 sub format_value {
-    my $self = shift();
-    my $value = shift();
+    my $self = shift;
+    my $value = shift;
 
     my %dtargs = (
         'epoch' => $value
     );
-    if($self->time_zone()) {
-        $dtargs{'time_zone'} = $self->time_zone();
+    if($self->time_zone) {
+        $dtargs{'time_zone'} = $self->time_zone;
     }
     my $dt = DateTime->from_epoch(%dtargs);
 
-    return $dt->strftime($self->format());
+    return $dt->strftime($self->format);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -129,10 +137,19 @@ no Moose;
 
 1;
 __END__
+=pod
 
 =head1 NAME
 
-Chart::Clicker::Axis::DateTime
+Chart::Clicker::Axis::DateTime - An X or Y Axis using DateTime
+
+=head1 VERSION
+
+version 2.70
+
+=head1 SYNOPSIS
+
+  my $axis = Chart::Clicker::Axis::DateTime->new;
 
 =head1 DESCRIPTION
 
@@ -140,28 +157,20 @@ A temporal Axis.  Requires L<DateTime> and L<DateTime::Set>.  Inherits from
 Axis, so check the methods there as well.  Expects that times will be in
 unix format.
 
-=head1 SYNOPSIS
-
-  my $axis = Chart::Clicker::Axis::DateTime->new;
-
 =head1 ATTRIBUTES
 
-=head2 time_zone
-
-Set/Get the time zone to use when creating DateTime objects!  Accepts an
-object or a string ('America/Chicago').
-
 =head2 format
 
 Set/Get the formatting string used to format the DateTime.  See DateTime's
 strftime.
 
+=head2 time_zone
+
+Set/Get the time zone to use when creating DateTime objects!  Accepts an
+object or a string ('America/Chicago').
+
 =head1 METHODS
 
-=head2 new
-
-Creates a new DateTime Axis.
-
 =head2 format_value
 
 Formats the value using L<DateTime>'s strftime.
@@ -170,11 +179,12 @@ Formats the value using L<DateTime>'s strftime.
 
 Cory G Watson <gphat@cpan.org>
 
-=head1 SEE ALSO
+=head1 COPYRIGHT AND LICENSE
 
-perl(1)
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-You can redistribute and/or modify this code under the same terms as Perl
-itself.
