@@ -1,10 +1,16 @@
 package Chart::Clicker::Component;
+BEGIN {
+  $Chart::Clicker::Component::VERSION = '2.70';
+}
 use Moose;
 
 extends 'Graphics::Primitive::Component';
 
 with 'Graphics::Primitive::Oriented';
 
+# ABSTRACT: Base class that extends Graphics::Primitive::Component
+
+
 has 'clicker' => (
     is => 'rw',
     isa => 'Chart::Clicker'
@@ -16,38 +22,36 @@ no Moose;
 
 1;
 __END__
+=pod
 
 =head1 NAME
 
 Chart::Clicker::Component - Base class that extends Graphics::Primitive::Component
 
+=head1 VERSION
+
+version 2.70
+
 =head1 DESCRIPTION
 
 Chart::Clicker::Component is a subclass of L<Graphics::Primitive::Component>.
 
-=head1 SYNOPSIS
-
 =head1 ATTRIBUTES
 
 =head2 clicker
 
 Set/Get this component's clicker object.
 
-=head1 METHODS
-
-=head2 new
-
-Creates a new Chart::Clicker::Component
-
 =head1 AUTHOR
 
 Cory G Watson <gphat@cpan.org>
 
-=head1 SEE ALSO
+=head1 COPYRIGHT AND LICENSE
 
-perl(1)
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-You can redistribute and/or modify this code under the same terms as Perl
-itself.
