@@ -1,21 +1,25 @@
 package Chart::Clicker::Decoration::Plot;
+BEGIN {
+  $Chart::Clicker::Decoration::Plot::VERSION = '2.70';
+}
 use Moose;
 
+# ABSTRACT: Area on which renderers draw
+
 use Layout::Manager::Axis;
 use Layout::Manager::Single;
 
 use Chart::Clicker::Decoration::Grid;
 
-# TODO READD THIS
-#use Chart::Clicker::Decoration::MarkerOverlay;
-
-# TODO MOve this class?  It's not decoration anymore.
 extends 'Chart::Clicker::Container';
 
+
 has 'clicker' => (
     is => 'rw',
     isa => 'Chart::Clicker',
 );
+
+
 has 'grid' => (
     is => 'rw',
     isa => 'Chart::Clicker::Decoration::Grid',
@@ -23,9 +27,13 @@ has 'grid' => (
         Chart::Clicker::Decoration::Grid->new( name => 'grid' )
     }
 );
+
+
 has '+layout_manager' => (
     default => sub { Layout::Manager::Axis->new }
 );
+
+
 has 'render_area' => (
     is => 'rw',
     isa => 'Chart::Clicker::Container',
@@ -59,18 +67,21 @@ no Moose;
 
 1;
 __END__
+=pod
 
 =head1 NAME
 
 Chart::Clicker::Decoration::Plot - Area on which renderers draw
 
+=head1 VERSION
+
+version 2.70
+
 =head1 DESCRIPTION
 
 A Component that handles the rendering of data via Renderers.  Also
 handles rendering the markers that come from the Clicker object.
 
-=head1 SYNOPSIS
-
 =head1 ATTRIBUTES
 
 =head2 background_color
@@ -81,45 +92,29 @@ Set/Get this Plot's background color.
 
 Set/Get this Plot's border.
 
-=head2 clicker
-
-Set/Get this Plot's clicker instance.
-
-=head2 markers
-
-Set/Get the flag that determines if markers are drawn on this plot.
-
-=head1 METHODS
-
-=head2 new
-
-Creates a new Plot object.
-
-=head2 draw
-
-Draw this Plot
-
 =head2 grid
 
 Set/Get the Grid component used on this plot.
 
-=head2 layout
+=head2 layout_manager
 
-Set/Get this Plot's layout.  See L<Layout::Manager>.
+Set/Get the layout manager for this plot.  Defaults to
+L<Layout::Manager::Axis>.
 
-=head2 prepare
+=head2 render_area
 
-Prepare this Plot by determining how much space it needs.
+Set/Get the container used to render within.
 
 =head1 AUTHOR
 
 Cory G Watson <gphat@cpan.org>
 
-=head1 SEE ALSO
+=head1 COPYRIGHT AND LICENSE
 
-perl(1)
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-You can redistribute and/or modify this code under the same terms as Perl
-itself.
