@@ -1,10 +1,15 @@
 package Chart::Clicker::Drawing::ColorAllocator;
+BEGIN {
+  $Chart::Clicker::Drawing::ColorAllocator::VERSION = '2.70';
+}
 use Moose;
 
+# ABSTRACT: Color picker
+
 use Graphics::Color::RGB;
 use Color::Scheme;
 
-my @defaults = (qw());;
+
 
 has 'colors' => (
     traits => [ 'Array' ],
@@ -18,14 +23,18 @@ has 'colors' => (
         'get_color' => 'get'
     }
 );
+
+
 has 'position' => ( is => 'rw', isa => 'Int', default => -1 );
 
+
 has 'color_scheme' => (
     is => 'rw',
     isa => 'Color::Scheme',
     lazy_build => 1,
 );
 
+
 has 'seed_hue' => (
     is => 'rw',
     isa => 'Int',
@@ -33,6 +42,7 @@ has 'seed_hue' => (
     default => sub { 270 },
 );
 
+
 has hues => (
     is => 'rw',
     isa => 'ArrayRef',
@@ -44,6 +54,7 @@ has hues => (
     },
 );
 
+
 has shade_order => (
     is => 'rw',
     isa => 'ArrayRef',
@@ -60,25 +71,27 @@ sub _build_color_scheme {
   return $scheme;
 }
 
+
 sub next {
-    my $self = shift();
+    my $self = shift;
 
-    $self->position($self->position() + 1);
+    $self->position($self->position + 1);
 
-    return $self->colors->[$self->position()];
+    return $self->colors->[$self->position];
 }
 
 # Before we attempt to get the next color, we'll instantiate it if we need it
 # that way we don't waste a bunch of memory with useless colors.
 before 'next' => sub {
-    my $self = shift();
+    my $self = shift;
 
-    my $pos = $self->position();
+    my $pos = $self->position;
     if(!defined($self->colors->[$pos + 1])) {
         $self->add_to_colors($self->allocate_color);
     }
 };
 
+
 sub allocate_color {
   my $self = shift;
 
@@ -103,8 +116,9 @@ sub allocate_color {
   )
 }
 
+
 sub reset {
-    my $self = shift();
+    my $self = shift;
 
     $self->position(-1);
     return 1;
@@ -116,15 +130,15 @@ no Moose;
 
 1;
 __END__
+=pod
 
 =head1 NAME
 
-Chart::Clicker::Drawing::ColorAllocator
+Chart::Clicker::Drawing::ColorAllocator - Color picker
 
-=head1 DESCRIPTION
+=head1 VERSION
 
-Allocates colors for use in the chart.  The position in the color allocator
-corresponds to the series that will be colored.
+version 2.70
 
 =head1 SYNOPSIS
 
@@ -136,17 +150,22 @@ corresponds to the series that will be colored.
             Graphics::Color::RGB->new(
                 red => 1.0, green => 0, blue => 0, alpha => 1.0
             ),
-            ...
+            #...
         )
     });
 
     my $red = $ca->get(0);
 
     #or let Chart::Clicker autmatically pick complementing colors for you
-    my $ca = Chart::Clicker::Drawing::ColorAllocator->new({
+    my $ca2 = Chart::Clicker::Drawing::ColorAllocator->new({
         seed_hue => 0, #red
     });
 
+=head1 DESCRIPTION
+
+Allocates colors for use in the chart.  The position in the color allocator
+corresponds to the series that will be colored.
+
 =head1 AUTOMATIC COLOR ALLOCATION
 
 This module has the capacity to automatically allocate 96 individual colors
@@ -158,19 +177,21 @@ values of C<hues> have been utilized, it repeats them using a different shade.
 This has the effect of generating evenly spaced complementing colors to ensure
 colors are well ditinguishable from one another and have appropriate contrast.
 
+=head2 position
+
+Gets the current position.
+
 =head1 ATTRIBUTES
 
+=head2 colors
+
+An arrayref of colors that will be used for series that Clicker draws.
+
 =head2 color_scheme
 
 A lazy-building L<Color::Scheme> object used to generate the color scheme of
 the chart;
 
-=head2 hues
-
-An array reference of evenly spaced seed hues for color allocation. By default
-it will use the seed hue plus 0, 45, 75, 15, 60 and 30 which is enough to cover
-all web-safe colors when using a tetrade color scheme.
-
 =head2 seed_hue
 
 The interger value of the first hue used when computing the tetrade color
@@ -179,6 +200,12 @@ Subsequent colors will be allocated based on their distance from this color
 to maintain sifficient contrast between colors. If not specified the seed_hue
 will default to 270, blue.
 
+=head2 hues
+
+An array reference of evenly spaced seed hues for color allocation. By default
+it will use the seed hue plus 0, 45, 75, 15, 60 and 30 which is enough to cover
+all web-safe colors when using a tetrade color scheme.
+
 =head2 shade_order
 
 An array reference of the order in which the different shades of each color
@@ -187,11 +214,6 @@ optimum color spacing.
 
 =head1 METHODS
 
-=head2 new
-
-Create a new ColorAllocator.  You can optionally pass an arrayref of colors
-to 'seed' the allocator.
-
 =head2 add_to_colors
 
 Add a color to this allocator.
@@ -204,15 +226,11 @@ Clear this allocator's colors
 
 Get the number of colors in this allocator.
 
-=head2 get_color
+=head2 get_color ($index)
 
 Gets the color at the specified index.  Returns undef if that position has no
 color.
 
-=head2 position
-
-Gets the current position.
-
 =head2 next
 
 Returns the next color.  Each call to next increments the position, so
@@ -230,11 +248,12 @@ Resets this allocator back to the beginning.
 
 Cory G Watson <gphat@cpan.org>
 
-=head1 SEE ALSO
+=head1 COPYRIGHT AND LICENSE
 
-perl(1)
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-You can redistribute and/or modify this code under the same terms as Perl
-itself.
