@@ -1,6 +1,11 @@
 package Chart::Clicker::Renderer::Point;
+BEGIN {
+  $Chart::Clicker::Renderer::Point::VERSION = '2.70';
+}
 use Moose;
 
+# ABSTRACT: Point renderer
+
 extends 'Chart::Clicker::Renderer';
 
 use Geometry::Primitive::Circle;
@@ -8,6 +13,7 @@ use Geometry::Primitive::Point;
 use Graphics::Primitive::Operation::Fill;
 use Graphics::Primitive::Paint::Solid;
 
+
 has 'shape' => (
     is => 'rw',
     does => 'Geometry::Primitive::Shape',
@@ -17,6 +23,8 @@ has 'shape' => (
         });
     }
 );
+
+
 has 'shape_brush' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Brush',
@@ -76,6 +84,7 @@ override('finalize', sub {
     return 1;
 });
 
+
 sub draw_point {
     my ($self, $x, $y, $series, $count) = @_;
 
@@ -90,31 +99,32 @@ no Moose;
 
 1;
 __END__
+=pod
 
 =head1 NAME
 
-Chart::Clicker::Renderer::Point
+Chart::Clicker::Renderer::Point - Point renderer
 
-=head1 DESCRIPTION
+=head1 VERSION
 
-Chart::Clicker::Renderer::Point renders a dataset as points.
-
-=begin HTML
-
-<p><img src="http://www.onemogin.com/clicker/chart-clicker-examples/point/point.png" width="500" height="250" alt="Point Chart" /></p>
-
-=end HTML
+version 2.70
 
 =head1 SYNOPSIS
 
   my $pr = Chart::Clicker::Renderer::Point->new({
-    shape => Chart::Clicker::Shape::Arc->new({
+    shape => Geometry::Primitive::Arc->new({
         angle1 => 0,
         angle2 => 180,
         radius  => 5
     })
   });
 
+=head1 DESCRIPTION
+
+Chart::Clicker::Renderer::Point renders a dataset as points.
+
+=for HTML <p><img src="http://www.onemogin.com/clicker/chart-clicker-examples/point/point.png" width="500" height="250" alt="Point Chart" /></p>
+
 =head1 ATTRIBUTES
 
 =head2 shape
@@ -128,28 +138,21 @@ Optionally provide a brush with with to stroke each point.
 
 =head1 METHODS
 
-=head2 new
-
-Create a new Point renderer
-
 =head2 draw_point
 
 Called for each point.  Implemented as a separate method so that subclasses
 such as Bubble may override the drawing.
 
-=head2 render
-
-Render the series.
-
 =head1 AUTHOR
 
 Cory G Watson <gphat@cpan.org>
 
-=head1 SEE ALSO
+=head1 COPYRIGHT AND LICENSE
 
-perl(1)
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-You can redistribute and/or modify this code under the same terms as Perl
-itself.
